@@ -25,6 +25,7 @@
 #'
 #' @examples
 #' ## Overdetermined System
+#' set.seed(100)
 #' A = matrix(rnorm(10*5),nrow=10)
 #' x = rnorm(5)
 #' b = A%*%x
@@ -50,7 +51,7 @@ lsolve.ssor <- function(A,B,xinit=NA,reltol=1e-5,maxiter=1000,w=1,adjsym=TRUE,ve
   # Preprocessing : sparsity
   # http://dirk.eddelbuettel.com/tmp/RcppArmadillo-sparseMatrix.pdf
   sparseformats = c("dgCMatrix","dtCMatrix","dsCMatrix")
-  if ((class(A)%in%sparseformats)||(class(B)%in%sparseformats)){
+  if (aux.is.sparse(A)||aux.is.sparse(B)){
     A = Matrix(A,sparse=TRUE)
     B = Matrix(B,sparse=TRUE)
     sparseflag = TRUE
